# Changing page layout

CjkCMS has 25+ bootstrap-based themes built in. You can change the layout of your page by selecting a theme from the `Layout` dropdown in the `Settings` tab of the admin interface.

There are three elements that can be changed:

1. Navbar: leave default to auto-adjust to the theme, or force a light or dark navbar.

2. Navbar CSS - add custom CSS class to the navbar, e.g. "bg-dark text-white", or "text-primary" etc.

3. The main theme for the website. Under `Theming`, choose one of available themes based on CDN Bootstrap 5 CSS. Alternatively, choose `Python Webpack Boilerplate` to use a custom-built theme. 

To use the `Webpack boilerplate`, quick-start a your project using `template=webpack` option, or see [here](https://github.com/AccordBox/python-webpack-boilerplate) for instructions of manual integration of the webpack boilerplate.

CjkCMS offers: 
- standard Bootstrap 5 theme
- all [Bootswatch](https://bootswatch.com/) themes
- light and dark [MDBootstrap](https://mdbootstrap.com/) themes